# praat script 
# script_name = "NegSomat_1_cut.praat"
# Version1.0 [2011:03:31]
# Original script name "save_intervals_to_wav_sound_files.praat"
# This script is distributed under the GNU General Public License.
# Copyright 8.3.2002 Mietta Lennes
# Modified on [2011:03:31] by Marco Tettamanti (email tettamanti.marco@hsr.it)
# also with parts from the original script_name "analyse_tier.praat" (version [2009:08:07])
# by Daniel Hirst (email daniel.hirst@lpl.univ-aix.fr)

# Adapted for sentence processing: the script now asks for the
# starting and ending intervals and creates a separate WAV sound file from start to end,
# discarding any intervals that come before or after (e.g. silence).
# Th script now works iteratively for all sound files in a folder.
#
# The source sounds must be LongSound objects.
# Both the TextGrid and the LongSound must have identical names.

#define parameters used in the script
form Define all parameters
	sentence Sound_folder Corpus/Sounds
	sentence TextGrid_folder Corpus/TextGrids
	comment Which Tier in this TextGrid would you like to process?
	integer Tier 1
	comment Starting and ending at which interval?
	comment (a separate WAV sound file including intervals from start to end will be created)
	integer Start_from 2
	integer End_at_(0=last) 4
	word Sound_extension .wav
	word TextGrid_extension .TextGrid
endform


#Read in list of sound files
mySounds = Create Strings as file list... sounds
... 'sound_folder$'/*'sound_extension$'
nSounds = Get number of strings
item = 0

myTextGrids = Create Strings as file list... TextGrids
... 'textGrid_folder$'/*'textGrid_extension$'
nTextGrids = Get number of strings

if nSounds > 0 and nTextGrids > 0
	nSounds = Get number of strings

#check if TextGrid file exists for each sound
# and call treatment
	for iSound from 1 to nSounds
		select mySounds
		sound_name$ = Get string... iSound
		textGrid_name$ = sound_name$ - sound_extension$
		... + textGrid_extension$
		sound$ = sound_folder$ + "/" + sound_name$
		textGrid$ = textGrid_folder$ + "/" + textGrid_name$
		if fileReadable(textGrid$)
			call cuttier
		else
			printline # Cannot find TextGrid file
			...  ['textGrid_name$']
		endif
	endfor
else
	if nSounds = 0
		printline Folder ['sound_folder$'] doesn't contain
		... any files with extension ['sound_extension$']
	elsif nTextGrids = 0
		printline Folder ['textGrid_folder$'] doesn't contain
		... any files with extension ['textGrid_extension$']
	endif
endif

#Remove file list
select mySounds
plus myTextGrids
Remove

exit

#subroutine cuttier
procedure cuttier
	Open long sound file... 'sound$'
	soundname$ = selected$("LongSound")
	Read from file... 'textGrid$'
	select TextGrid 'soundname$'

	numberOfIntervals = Get number of intervals... tier
	if start_from > numberOfIntervals
		exit There are not that many intervals in the IntervalTier!
	endif
	if end_at > numberOfIntervals
		end_at = numberOfIntervals
	endif
	if end_at = 0
		end_at = numberOfIntervals
	endif

	# Default values for variables
	intervalstart = 0
	intervalend = 0

	# Defines time extension from starting interval to ending interval
	intervalS=start_from
		intervalstart = Get starting point... tier intervalS
	intervalE=end_at
		intervalend = Get end point... tier intervalE
	
	select LongSound 'soundname$'
	Extract part... intervalstart intervalend no
	# The name of the sound file then consists of these elements:
	intervalfile$ = "'Sound_folder$'" + "/" + "'soundname$'" + "_cut" + ".wav"
	Write to WAV file... 'intervalfile$'
	Remove

	#Remove Sound and TextGrid
	select LongSound 'soundname$'
	Remove
	select TextGrid 'soundname$'
	Remove
endproc
