# praat script 
# script_name = "NegSomat_3_shiftTextGrid.praat"
# Version1.0 [2011:03:31]
# Created by Marco Tettamanti (email tettamanti.marco@hsr.it)
# with parts from the original script_name "analyse_tier.praat" (version [2009:08:07])
# by Daniel Hirst (email daniel.hirst@lpl.univ-aix.fr)

# The script is meant to work in association with the script NegSomat_1_cut.praat":
# if a number of intervals have been removed from a WAV file (e.g. silence),
# this script allows the removal of the corresponding intervals
# from the associated TextGrid file, setting the start time of the first kept interval to 0 ms.
# This script is thus propedeutic to running script "NegSomat_4_onset_offset_dur_pitch_intensity.praat"
# The script works iteratively for all sound files in a folder.
# The script by default requires the presence of files with extension
# .TextGrid in the target folder.

#define parameters used in the script
form Define all parameters
	sentence TextGrid_folder Corpus/TextGrids
	comment Which Interval in this TextGrid would you like to process?
	integer Tier 1
	comment Starting at which interval?
	integer Start_from 2
	word TextGrid_extension .TextGrid
endform


myTextGrids = Create Strings as file list... TextGrids
... 'textGrid_folder$'/*'textGrid_extension$'
nTextGrids = Get number of strings

if nTextGrids > 0
	nTextGrids = Get number of strings

#call treatment
	for iTextGrids from 1 to nTextGrids
		select myTextGrids
		textGrid_name$ = Get string... iTextGrids
		textGrid$ = textGrid_folder$ + "/" + textGrid_name$
		call shiftinterval
	endfor

#Remove file list
select myTextGrids
Remove

exit

#subroutine shiftinterval
procedure shiftinterval
	Read from file... 'textGrid$'
	gridname$ = selected$("TextGrid")
	select TextGrid 'gridname$'
	numberOfIntervals = Get number of intervals... tier
	if start_from > numberOfIntervals
		exit There are not enough intervals in the IntervalTier!
	endif
	# Default values for variables
	intervalstart = 0
	# Defines time extension from starting interval to ending interval
	interval=start_from
	intervalstart = Get starting point... tier interval
	Shift times by... -intervalstart
	# The name of the sound file then consists of these elements:
	intervalfile$ = "'TextGrid_folder$'" + "/" + "'gridname$'" + "_cut_norm" + ".TextGrid"
	Write to text file... 'intervalfile$'
	Remove

endproc
